// Función para limpiar texto
function limpiarTexto(texto) {
    // Convertir a minúsculas
    texto = texto.toLowerCase();

    // Reemplazar vocales con tilde
    texto = texto.normalize('NFD')
    .replace(/[\u0300-\u036f]/g, '')
    .replace(/[¿?!¡]/g, '');

    return texto.trim();
}

// Función para encontrar palabras clave
function encontrarPalabrasClave(texto) {
    texto = limpiarTexto(texto);
    const palabrasEncontradas = [];

    // Revisar cada categoría de palabras clave
    for (let categoria in diccionario) {
        const palabrasClave = diccionario[categoria].palabras;

        // Buscar si alguna palabra clave está en el texto
        palabrasClave.forEach(palabra => {
            if (texto.includes(palabra)) {
                palabrasEncontradas.push(categoria);
            }
        });
    }

    return palabrasEncontradas;
}

const mensajesContainer = document.getElementById('mensajes');
const entradaMensaje = document.getElementById('texto-mensaje');

function enviarMensaje() {
    const mensaje = entradaMensaje.value;
    if (!mensaje) return;

    // Mostrar mensaje del usuario
    mostrarMensaje('usuario', mensaje);

    // Encontrar palabras clave
    const palabrasClave = encontrarPalabrasClave(mensaje);

    // Generar respuestas basadas en palabras clave
    if (palabrasClave.length > 0) {
        palabrasClave.forEach(categoria => {
            const respuestasCategoria = diccionario[categoria].respuestas;
            const respuestaAleatoria = respuestasCategoria[Math.floor(Math.random() * respuestasCategoria.length)];
            mostrarMensaje('bot', respuestaAleatoria);
        });
    } else {
        // Respuesta por defecto
        mostrarMensaje('bot', 
            'Lo siento, no comprendo completamente tu mensaje. ¿Podrías ser más específico?'
            );
    }

    // Limpiar entrada
    entradaMensaje.value = '';
}

function mostrarMensaje(tipo, texto) {
    const mensajeDiv = document.createElement('div');
    mensajeDiv.classList.add(tipo);
    mensajeDiv.textContent = texto;
    mensajesContainer.appendChild(mensajeDiv);

    mensajesContainer.scrollTop = mensajesContainer.scrollHeight;
}

// Eventos de teclado
entradaMensaje.addEventListener('keypress', (e) => {
    if (e.key === 'Enter') {
        enviarMensaje();
    }
});

// Mensaje de bienvenida
mostrarMensaje('bot', 
    "¡Hola! Soy tu asistente virtual. Estoy aquí para ayudarte."
    );